create_clock -period 4.0 -name fpga_clk [get_ports fpga_clk]

# Constrains PLL outputs.  One output has 90 degree phase-shift for transmit clock
derive_pll_clocks

derive_clock_uncertainty



################### FPGA -> 5681 Interface ####################

# Put a generated clock on output clock port to be referenced by set_output_delay constraints
create_generated_clock -source [get_pins {inst1|altpll_component|auto_generated|pll1|clk[0]}] -name ssync_tx_clk_ext [get_ports {ssync_tx_clk}] -phase 90


# TI 5681 Datasheet allows DCLK to be skewed +600ps to -1000ps compared to Data
# We need to reverse those, since TimeQuest always compares the data path to the clk.
set dac_allowed_data2dclk_skew_max 1.0
set dac_allowed_data2dclk_skew_min -0.6
# This does not directly tell us what the DAC is doing.  So we need to work back from the setup and hold relationships
# which are +1ns and -1ns. 
set ninety_degrees 1.0 ;# This number must be changed if the clock period changes
set dac_data2dclk_skew_max [expr $ninety_degrees - $dac_allowed_data2dclk_skew_max] ;# 1.0 - 1.0 = 0.0
set dac_data2dclk_skew_min [expr -$ninety_degrees - $dac_allowed_data2dclk_skew_min] ;# -1 - (-0.6) = -0.4


# The board skew need to be accounted for.  Positive means data is longer than clk, negative means it is shorter than clk.
set board_data2dclk_skew_max 0.1
set board_data2dclk_skew_min -0.1

# Now just add the board skew and DAC skew to calculate external delays:
set ssync_out_max [expr $dac_data2dclk_skew_max + $board_data2dclk_skew_max] ;# 0.0 + 0.1 = 0.1
set ssync_out_min [expr $dac_data2dclk_skew_min + $board_data2dclk_skew_min] ;# -0.4 + -0.1 = -0.5

set_output_delay -clock ssync_tx_clk_ext -max $ssync_out_max [get_ports {ssync_tx_data[*]}]
set_output_delay -clock ssync_tx_clk_ext -min $ssync_out_min [get_ports {ssync_tx_data[*]}]
set_output_delay -clock ssync_tx_clk_ext -max $ssync_out_max [get_ports {ssync_tx_data[*]}] -clock_fall -add_delay
set_output_delay -clock ssync_tx_clk_ext -min $ssync_out_min [get_ports {ssync_tx_data[*]}] -clock_fall -add_delay
###############################################################
